@@ -9,6 +9,7 @@ from gi.repository import Adw
 from gi.repository import GLib
 from gi.repository import Gtk
 
+from komikku.consts import LOGO_SIZE
 from komikku.models import Settings
 from komikku.models.database import clear_cached_data
 from komikku.models.keyring import KeyringHelper
@@ -143,11 +144,11 @@ class PreferencesDialog(Adw.PreferencesDialog):
             if self.window.previous_page == 'history':
                 self.window.history.populate()
 
-        self.window.confirm(
+        self.window.open_dialog(
             _('Clear?'),
-            _('Are you sure you want to clear chapters cache and database?'),
-            _('Clear'),
-            confirm_callback,
+            body=_('Are you sure you want to clear chapters cache and database?'),
+            confirm_label=_('Clear'),
+            confirm_callback=confirm_callback,
             confirm_appearance=Adw.ResponseAppearance.DESTRUCTIVE
         )
 
@@ -161,11 +162,11 @@ class PreferencesDialog(Adw.PreferencesDialog):
             self.window.webview.clear_data()
             self.update_webview_data_size()
 
-        self.window.confirm(
+        self.window.open_dialog(
             _('Clear?'),
-            _('Are you sure you want to clear WebView data (cache, storage, cookies)?'),
-            _('Clear'),
-            confirm_callback,
+            body=_('Are you sure you want to clear WebView data (cache, storage, cookies)?'),
+            confirm_label=_('Clear'),
+            confirm_callback=confirm_callback,
             confirm_appearance=Adw.ResponseAppearance.DESTRUCTIVE
         )
 
@@ -187,11 +188,12 @@ class PreferencesDialog(Adw.PreferencesDialog):
             Gtk.Settings.get_default().set_property('gtk-enable-animations', False)
 
         if switch_button.get_active():
-            self.window.confirm(
+            self.window.open_dialog(
                 _('Disable animations?'),
-                _('Are you sure you want to disable animations?\n\nThe gesture navigation in the reader will not work properly anymore.'),
-                _('Disable'),
-                on_confirm,
+                body=_('Are you sure you want to disable animations?\n\nThe gesture navigation in the reader will not work properly anymore.'),
+                confirm_label=_('Disable'),
+                confirm_callback=on_confirm,
+                confirm_appearance=Adw.ResponseAppearance.DESTRUCTIVE,
                 cancel_callback=on_cancel
             )
         elif self.settings.disable_animations:
@@ -771,9 +773,13 @@ class TrackerRow(Adw.ActionRow):
 
         super().__init__(title=self.tracker.name, activatable=False)
 
-        logo = Gtk.Picture.new_for_filename(self.tracker.logo_path)
-        logo.props.margin_top = 9
-        logo.props.margin_bottom = 9
+        if self.tracker.logo_path:
+            logo = Gtk.Image()
+            logo.set_pixel_size(LOGO_SIZE)
+            logo.set_from_file(self.tracker.logo_path)
+        else:
+            logo = Adw.Avatar.new(LOGO_SIZE, self.tracker.name, True)
+
         self.add_prefix(logo)
 
         self.btn = Gtk.Button(valign=Gtk.Align.CENTER)
@@ -788,7 +794,35 @@ class TrackerRow(Adw.ActionRow):
         self.add_suffix(self.btn)
 
     def on_btn_clicked(self, _btn):
-        def connect():
+        group = None
+
+        def open_dialog():
+            nonlocal group
+
+            group = Adw.PreferencesGroup()
+
+            username_entry = Adw.EntryRow(title=_('Username'))
+            username_entry.add_prefix(Gtk.Image.new_from_icon_name('avatar-default-symbolic'))
+            group.add(username_entry)
+
+            password_entry = Adw.PasswordEntryRow(title=_('Password'))
+            password_entry.add_prefix(Gtk.Image.new_from_icon_name('dialog-password-symbolic'))
+            group.add(password_entry)
+
+            self.window.open_dialog(
+                self.tracker.name,
+                child=group,
+                confirm_label=_('Connect'),
+                confirm_callback=connect_dialog
+            )
+
+        def connect_dialog():
+            username_entry = group.get_row(0)
+            password_entry = group.get_row(1)
+            success, error = self.tracker.get_access_token(username_entry.get_text(), password_entry.get_text())
+            GLib.idle_add(connect_finish, success, error)
+
+        def connect_webview():
             success, error = self.tracker.get_access_token()
             GLib.idle_add(connect_finish, success, error)
 
@@ -813,11 +847,17 @@ class TrackerRow(Adw.ActionRow):
             self.btn.set_label(_('Connect'))
 
         if not self.active:
-            thread = threading.Thread(target=connect)
-            thread.daemon = True
-            thread.start()
+            if self.tracker.authorize_url:
+                thread = threading.Thread(target=connect_webview)
+                thread.daemon = True
+                thread.start()
+            else:
+                open_dialog()
+
         else:
-            self.window.confirm(
-                _('Disconnect from {}').format(self.tracker.name), '', _('Disconnect'), disconnect,
+            self.window.open_dialog(
+                _('Disconnect from {}').format(self.tracker.name),
+                confirm_label=_('Disconnect'),
+                confirm_callback=disconnect,
                 confirm_appearance=Adw.ResponseAppearance.DESTRUCTIVE
             )
